window.Gleam.initSearch([{"doc":"cake_gmysql","title":"cake_gmysql","content":"# Adapter between `cake` and `gmysql`\n\n[![Package &lt;a href=&quot;https://github.com/inoas/gleam-cake-pgo/releases&quot;&gt;&lt;img src=&quot;https://img.shields.io/github/release/inoas/gleam-cake-gmysql&quot; alt=&quot;GitHub release&quot;&gt;&lt;/a&gt; Version](https://img.shields.io/hexpm/v/cake_gmysql)](https://hex.pm/packages/cake_gmysql)\n[![Erlang-compatible](https://img.shields.io/badge/target-erlang-b83998)](https://www.erlang.org/)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/cake_gmysql/)\n[![Discord](https://img.shields.io/discord/768594524158427167?label=discord%20chat&amp;amp;color=5865F2)](https://discord.gg/Fm8Pwmy)\n\n&lt;!--\n[![CI Test](https://github.com/inoas/gleam-cake-gmysql/actions/workflows/test.yml/badge.svg?branch=main&amp;amp;event=push)](https://github.com/inoas/gleam-cake-gmysql/actions/workflows/test.yml)\n--&gt;\n\n🎂[Cake](http://hex.pm/packages/cake) 🦭MariaDB and 🐬MySQL adapters which which pass `PreparedStatement`s to the [gmysql](http://hex.pm/packages/gmysql) library for execution written in [Gleam](https://gleam.run/).\n\n## Installation\n\n```sh\ngleam add cake_gmysql@1\n```\n\n## MariaDB Example\n\nNotice: Official cake adapters re-use the cake namespace, thus you can import\nthem like such: `import cake/adapter/mariadb`.\n\n```gleam\nimport cake/adapter/mariadb\nimport cake/delete as d\nimport cake/insert as i\nimport cake/select as s\nimport cake/where as w\nimport gleam/dynamic\nimport gleam/option.{None}\n\nconst mariadb_database_name = &quot;my_mariadb_database_name&quot;\n\npub fn main() {\n  mariadb.with_connection(\n    host: &quot;localhost&quot;,\n    port: 3306,\n    username: None,\n    password: None,\n    database: mariadb_database_name,\n    fn(db_connection) {\n      db_connection |&gt; create_table_if_not_exists_birds\n      db_connection |&gt; insert_into_table_birds\n      db_connection |&gt; select_from_table_birds\n      db_connection |&gt; delete_from_table_birds\n    }\n  )\n}\n\nfn create_table_if_not_exists_birds(db_connection) {\n  &quot;CREATE TABLE IF NOT EXISTS birds (\n    species TEXT,\n    average_weight FLOAT(8),\n    is_extinct BOOLEAN\n  );&quot;\n  |&gt; mariadb.execute_raw_sql(db_connection)\n  |&gt; io.debug\n}\n\nfn insert_into_table_birds(db_connection) {\n  [\n    [i.string(&quot;Dodo&quot;), i.float(14.05), i.bool(True)] |&gt; i.row,\n    [i.string(&quot;Great auk&quot;), i.float(5.0), i.bool(True)] |&gt; i.row,\n  ]\n  |&gt; i.from_values(\n      table_name: &quot;birds&quot;,\n      columns: [\n        &quot;species&quot;, &quot;average_weight&quot;, &quot;is_extinct&quot;,\n      ]\n  )\n  |&gt; i.to_query\n  |&gt; mariadb.run_write_query(dynamic.dynamic, db_connection)\n  |&gt; io.debug\n}\n\nfn select_from_table_birds(db_connection) {\n  s.new()\n  |&gt; s.from_table(&quot;table&quot;)\n  |&gt; s.selects([s.col(&quot;species&quot;)])\n  |&gt; s.to_query\n  |&gt; mariadb.run_read_query(dynamic.dynamic, db_connection)\n  |&gt; io.debug\n}\n\nfn delete_from_table_birds(db_connection) {\n  d.new()\n  |&gt; d.table(&quot;birds&quot;)\n  |&gt; d.where(w.col(&quot;species&quot;) |&gt; w.eq(w.string(&quot;Dodo&quot;)))\n  |&gt; d.to_query\n  |&gt; mariadb.run_write_query(dynamic.dynamic, db_connection)\n  |&gt; io.debug\n}\n```\n\n## MySQL Example\n\nNotice: Official cake adapters re-use the cake namespace, thus you can import\nthem like such: `import cake/adapter/mysql`.\n\n```gleam\nimport cake/adapter/mysql\nimport cake/delete as d\nimport cake/insert as i\nimport cake/select as s\nimport cake/where as w\nimport gleam/dynamic\nimport gleam/option.{None}\n\nconst mysql_database_name = &quot;my_mysql_database_name&quot;\n\npub fn main() {\n  mysql.with_connection(\n    host: &quot;localhost&quot;,\n    port: 3306,\n    username: None,\n    password: None,\n    database: mysql_database_name,\n    fn(db_connection) {\n      db_connection |&gt; create_table_if_not_exists_birds\n      db_connection |&gt; insert_into_table_birds\n      db_connection |&gt; select_from_table_birds\n      db_connection |&gt; delete_from_table_birds\n    }\n  )\n}\n\nfn create_table_if_not_exists_birds(db_connection) {\n  &quot;CREATE TABLE IF NOT EXISTS birds (\n    species TEXT,\n    average_weight FLOAT(8),\n    is_extinct BOOLEAN\n  );&quot;\n  |&gt; mysql.execute_raw_sql(db_connection)\n  |&gt; io.debug\n}\n\nfn insert_into_table_birds(db_connection) {\n  [\n    [i.string(&quot;Dodo&quot;), i.float(14.05), i.bool(True)] |&gt; i.row,\n    [i.string(&quot;Great auk&quot;), i.float(5.0), i.bool(True)] |&gt; i.row,\n  ]\n  |&gt; i.from_values(\n      table_name: &quot;birds&quot;,\n      columns: [\n        &quot;species&quot;, &quot;average_weight&quot;, &quot;is_extinct&quot;,\n      ]\n  )\n  |&gt; i.to_query\n  |&gt; mysql.run_write_query(dynamic.dynamic, db_connection)\n  |&gt; io.debug\n}\n\nfn select_from_table_birds(db_connection) {\n  s.new()\n  |&gt; s.from_table(&quot;table&quot;)\n  |&gt; s.selects([s.col(&quot;species&quot;)])\n  |&gt; s.to_query\n  |&gt; mysql.run_read_query(dynamic.dynamic, db_connection)\n  |&gt; io.debug\n}\n\nfn delete_from_table_birds(db_connection) {\n  d.new()\n  |&gt; d.table(&quot;birds&quot;)\n  |&gt; d.where(w.col(&quot;species&quot;) |&gt; w.eq(w.string(&quot;Dodo&quot;)))\n  |&gt; d.to_query\n  |&gt; mysql.run_write_query(dynamic.dynamic, db_connection)\n  |&gt; io.debug\n}\n```\n","url":"index.html"},{"doc":"cake_gmysql","title":"cake_gmysql","content":"# Changelog\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/), and this project adheres to\n[Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n&lt;!-- ## [Unreleased] --&gt;\n\n## [1.0.1] - 2024-10-20\n\n- Relaxed dependency version constraints.\n\n## [1.0.0] - 2024-10-19\n\n- Initial release.\n","url":"changelog.html"},{"doc":"cake/adapter/maria","title":"execute_raw_sql","content":"pub fn execute_raw_sql(\n  query_string query_string: String,\n  db_connection db_connection: Connection,\n) -&gt; Result(Nil, Error)\n Execute a raw SQL query against an 🦭MariaDB database.\n\nSynonyms:\ncake/adapter/maria.execute_raw_sql\ncake/adapter/maria execute_raw_sql","url":"cake/adapter/maria.html#execute_raw_sql"},{"doc":"cake/adapter/maria","title":"read_query_to_prepared_statement","content":"pub fn read_query_to_prepared_statement(\n  query query: ReadQuery,\n) -&gt; PreparedStatement\n Convert a Cake `ReadQuery` to a `PreparedStatement`.\n\nSynonyms:\ncake/adapter/maria.read_query_to_prepared_statement\ncake/adapter/maria read_query_to_prepared_statement","url":"cake/adapter/maria.html#read_query_to_prepared_statement"},{"doc":"cake/adapter/maria","title":"run_query","content":"pub fn run_query(\n  query query: CakeQuery(a),\n  decoder decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  db_connection db_connection: Connection,\n) -&gt; Result(List(a), Error)\n Run a Cake `CakeQuery` against an 🦭MariaDB database.\n\n This function is a wrapper around `run_read_query` and `run_write_query`.\n\nSynonyms:\ncake/adapter/maria.run_query\ncake/adapter/maria run_query","url":"cake/adapter/maria.html#run_query"},{"doc":"cake/adapter/maria","title":"run_read_query","content":"pub fn run_read_query(\n  query query: ReadQuery,\n  decoder decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  db_connection db_connection: Connection,\n) -&gt; Result(List(a), Error)\n\nSynonyms:\ncake/adapter/maria.run_read_query\ncake/adapter/maria run_read_query","url":"cake/adapter/maria.html#run_read_query"},{"doc":"cake/adapter/maria","title":"run_write_query","content":"pub fn run_write_query(\n  query query: WriteQuery(a),\n  decoder decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  db_connection db_connection: Connection,\n) -&gt; Result(List(a), Error)\n Run a Cake `WriteQuery` against an 🦭MariaDB database.\n\nSynonyms:\ncake/adapter/maria.run_write_query\ncake/adapter/maria run_write_query","url":"cake/adapter/maria.html#run_write_query"},{"doc":"cake/adapter/maria","title":"with_connection","content":"pub fn with_connection(\n  host host: String,\n  port port: Int,\n  username username: Option(String),\n  password password: Option(String),\n  database database: String,\n  callback callback: fn(Connection) -&gt; a,\n) -&gt; a\n Connection to a 🦭MariaDB database.\n\n This is a thin wrapper around the `gmysql` library&#39;s `Connection` type.\n\nSynonyms:\ncake/adapter/maria.with_connection\ncake/adapter/maria with_connection","url":"cake/adapter/maria.html#with_connection"},{"doc":"cake/adapter/maria","title":"write_query_to_prepared_statement","content":"pub fn write_query_to_prepared_statement(\n  query query: WriteQuery(a),\n) -&gt; PreparedStatement\n Convert a Cake `WriteQuery` to a `PreparedStatement`.\n\nSynonyms:\ncake/adapter/maria.write_query_to_prepared_statement\ncake/adapter/maria write_query_to_prepared_statement","url":"cake/adapter/maria.html#write_query_to_prepared_statement"},{"doc":"cake/adapter/maria","title":"cake/adapter/maria","content":" 🎂Cake 🦭MariaDB adapter which which passes `PreparedStatement`s\n to the `gmysql` library for execution.\n","url":"cake/adapter/maria.html"},{"doc":"cake/adapter/mysql","title":"execute_raw_sql","content":"pub fn execute_raw_sql(\n  query_string query_string: String,\n  db_connection db_connection: Connection,\n) -&gt; Result(Nil, Error)\n Execute a raw SQL query against an 🐬MySQL database.\n\nSynonyms:\ncake/adapter/mysql.execute_raw_sql\ncake/adapter/mysql execute_raw_sql","url":"cake/adapter/mysql.html#execute_raw_sql"},{"doc":"cake/adapter/mysql","title":"read_query_to_prepared_statement","content":"pub fn read_query_to_prepared_statement(\n  query query: ReadQuery,\n) -&gt; PreparedStatement\n Convert a Cake `ReadQuery` to a `PreparedStatement`.\n\nSynonyms:\ncake/adapter/mysql.read_query_to_prepared_statement\ncake/adapter/mysql read_query_to_prepared_statement","url":"cake/adapter/mysql.html#read_query_to_prepared_statement"},{"doc":"cake/adapter/mysql","title":"run_query","content":"pub fn run_query(\n  query query: CakeQuery(a),\n  decoder decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  db_connection db_connection: Connection,\n) -&gt; Result(List(a), Error)\n Run a Cake `CakeQuery` against an 🐬MySQL database.\n\n This function is a wrapper around `run_read_query` and `run_write_query`.\n\nSynonyms:\ncake/adapter/mysql.run_query\ncake/adapter/mysql run_query","url":"cake/adapter/mysql.html#run_query"},{"doc":"cake/adapter/mysql","title":"run_read_query","content":"pub fn run_read_query(\n  query query: ReadQuery,\n  decoder decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  db_connection db_connection: Connection,\n) -&gt; Result(List(a), Error)\n\nSynonyms:\ncake/adapter/mysql.run_read_query\ncake/adapter/mysql run_read_query","url":"cake/adapter/mysql.html#run_read_query"},{"doc":"cake/adapter/mysql","title":"run_write_query","content":"pub fn run_write_query(\n  query query: WriteQuery(a),\n  decoder decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  db_connection db_connection: Connection,\n) -&gt; Result(List(a), Error)\n Run a Cake `WriteQuery` against an 🐬MySQL database.\n\nSynonyms:\ncake/adapter/mysql.run_write_query\ncake/adapter/mysql run_write_query","url":"cake/adapter/mysql.html#run_write_query"},{"doc":"cake/adapter/mysql","title":"with_connection","content":"pub fn with_connection(\n  host host: String,\n  port port: Int,\n  username username: Option(String),\n  password password: Option(String),\n  database database: String,\n  callback callback: fn(Connection) -&gt; a,\n) -&gt; a\n Connection to a 🐬MySQL database.\n\n This is a thin wrapper around the `gmysql` library&#39;s `Connection` type.\n\nSynonyms:\ncake/adapter/mysql.with_connection\ncake/adapter/mysql with_connection","url":"cake/adapter/mysql.html#with_connection"},{"doc":"cake/adapter/mysql","title":"write_query_to_prepared_statement","content":"pub fn write_query_to_prepared_statement(\n  query query: WriteQuery(a),\n) -&gt; PreparedStatement\n Convert a Cake `WriteQuery` to a `PreparedStatement`.\n\nSynonyms:\ncake/adapter/mysql.write_query_to_prepared_statement\ncake/adapter/mysql write_query_to_prepared_statement","url":"cake/adapter/mysql.html#write_query_to_prepared_statement"},{"doc":"cake/adapter/mysql","title":"cake/adapter/mysql","content":" 🎂Cake 🐬MySQL adapter which which passes `PreparedStatement`s\n to the `gmysql` library for execution.\n","url":"cake/adapter/mysql.html"},{"doc":"cake_gmysql","title":"cake_gmysql","content":"","url":"cake_gmysql.html"}]);